<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy aplikacji</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ Proxy</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adres IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcjonalne</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Zaznacz „Użyj proxy” w menu kontekstowym aplikacji w programie wywołującym po skonfigurowaniu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Nieprawidłowy adres IP</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Nieprawidłowy port</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Rozłącz</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Rozłącz</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Czy na pewno chcesz usunąć tę konfigurację?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Połączenie przewodowe %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Połączenie bezprzewodowe %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Połączenie PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Nowy VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Typ VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksportuj</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy aplikacji</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Osobisty Hotspot</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Informacje o sieci</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy systemowe</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Sieć przewodowa</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Sieć bezprzewodowa</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Tryb samolotowy</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Przewodowa karta sieciowa</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Dodaj Połączenie Sieciowe</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Bezprzewodowa karta sieciowa</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Połącz z siecią ukrytą</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Utwórz połączenie PPPoE</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Status VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Utwórz VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importuj VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ Proxy</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Adres URL konfiguracji</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adres IP</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Utwórz Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfejs</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Pasmo</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama sieciowa</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Podstawowy DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sieci</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Prędkość</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Tryb samolotowy</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Włączenie trybu samolotowego wyłączy sieć bezprzewodową, osobisty Hotspot i Bluetooth</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Nieprawidłowy adres DNS</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nie znaleziono</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adres MAC urządzenia</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Sklonowany adres MAC</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Dostosuj MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Nazwa już istnieje</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Automatyczne połączenie</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Dodaj ustawienia</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Utwórz Hotspot</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Adres IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama sieciowa</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Zduplikowany adres IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Nieprawidłowy adres IP</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Nieprawidłowa maska sieci</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Tylko jedna bramka sieciowa jest dozwolona</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Nieprawidłowa brama sieciowa</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sieci</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Zduplikowany adres IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Nieprawidłowy adres IP</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Tylko jedna bramka sieciowa jest dozwolona</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Nieprawidłowa bramka</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ręcznie</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignoruj</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adres IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Mające zastosowanie tylko w zgodnych zasobach</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metoda</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sieci</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Nieprawidłowy adres IP</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Nieprawidłowa maska sieci</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Niepoprawna bramka</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Metoda</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ręcznie</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignoruj</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Szczegóły sieci</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy systemowe</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy aplikacji</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Tryb samolotowy</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Szczegóły sieci</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Wyłączone</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ręcznie</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Skonfiguruj przy użyciu menedżera sieci</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Osobisty Hotspot</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Usługa</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Odmowa uwierzytelnienia EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Odmowa uwierzytelnienia PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Odmowa uwierzytelnienia CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Odmowa uwierzytelnienia MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Odmowa uwierzytelnienia MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Brak kompresji danych BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Brak kompresji danych Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Brak kompresji nagłówka TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Brak kompresji pola protokołu</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Brak kompresji adresu/kontroli</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Wyślij pakiety echa PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Użyj MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bitowe MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stanowy MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Utwórz połączenie PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy systemowe</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ Proxy</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ręcznie</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcjonalne</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP Proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignoruj konfiguracje proxy dla powyższych hostów i domen</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Adres URL konfiguracji</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Bezpieczeństwo</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunelowany TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Zabezpieczony EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Zapisz hasło dla tego użytkownika</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Zapisz hasło dla wszystkich użytkowników</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Zawsze pytaj</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Wyłączone</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonimowo</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Uwierzytelniono</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Oba</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Wersja 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Wersja 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Uwierzytelnienie EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Tożsamość</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcje hasła</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Klucz prywatny</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certyfikat CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certyfikat użytkownika</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonimowo</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Zabezpieczanie</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Plik PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Wewnętrzne uwierzytelnienie</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Wersja PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Hasło prywatne</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Nieprawidłowe hasło</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Bezpieczeństwo</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Klucz</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Wymagane zabezpieczenie</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Nieprawidłowe hasło</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Wspólny klucz</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Otwarty system</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Bezpieczeństwo</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Uwierzytelnienie</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Klucz</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Zaawansowane VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Dostosuj port bramy</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Port bramy</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Dostosuj odstęp renegocjacji</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Odstęp renegocjacji</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Użyj kompresji danych LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Użyj połączenia TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Użyj urządzenia TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Dostosuj tunel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Dostosuj rozmiar fragmentu UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Rozmiar fragmentu UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Ogranicz tunel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Losowo wybieraj zdalne serwery</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Zaawansowane VPN</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (domyślnie)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Bezpieczny (domyślnie)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Słabe</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T gdy dostępne (domyślnie)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T zawsze</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Wyłączone</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Grupa 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Grupa 2 (domyślnie)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Grupa 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Serwer (domyślny)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Grupa 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domena</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Dostawca</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Tryb NAT Traversal</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Grupa IKE DH</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Forward Secrecy</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Port lokalny</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Wyłącz Dead Peer Detection</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>IPsec VPN</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Włącz IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nazwa grupy</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Identyfikator grupy</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Współdzielony klucz</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algorytmy fazy 1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algorytmy fazy 2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Nieprawidłowa bramka</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certyfikat CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Pozwól na pulpitowego trojana bezpieczeństwa Cisco</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Skrypt CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certyfikat użytkownika</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Klucz prywatny</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Użyj FSID jako hasła klucza</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Nieprawidłowa bramka</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certyfikaty (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certyfikaty z hasłem (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Klucz stały</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Zapisano</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Zapytaj</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Niewymagane</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Typ uwierzytelnienia</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certyfikat CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certyfikat użytkownika</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Klucz prywatny</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcje hasła</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Hasło prywatne</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Dostosuj kierunek klucza</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Kierunek klucza</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Zdalne IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Lokalne IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>PPP VPN</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Wszystkie dostępne (domyślnie)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bitowe (mniejsze bezpieczeństwo)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bitowe (najbardziej bezpieczne)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Odmowa uwierzytelnienia EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Odmowa uwierzytelnienia PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Odmowa uwierzytelnienia CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Odmowa uwierzytelnienia MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Odmowa uwierzytelnienia MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Brak kompresji danych BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Brak kompresji danych Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Brak kompresji nagłówka TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Brak kompresji pola protokołu</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Brak kompresji adresu/kontroli</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Wyślij pakiety echa PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Użyj MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Bezpieczeństwo</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stanowy MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Status VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Utwórz VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importuj VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Błąd importu</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Błąd pliku</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Niewymagane</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Serwer IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Ponawiaj nieustannie, gdy wystąpił błąd</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Plik CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignoruj ostrzeżenia certyfikatu</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Użyj rozszerzeń nazwy hosta TLS</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Zabezpieczenie VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Domyślne</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Szyfr</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Uwierzytelnienie HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Nieprawidłowa bramka</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Zapisano</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Zapytaj</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Niewymagane</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcje hasła</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domena NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Serwer IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Nieprawidłowa bramka</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Klucz prywatny</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agent SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Karta inteligentna</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Współdzielony klucz</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certyfikat CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Typ uwierzytelnienia</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certyfikat użytkownika</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Prośba o wewnętrzny adres IP</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Wymuszenie UDP Encapsulation</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Użyj kompresji IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Włącz niestandardowe propozycje szyfrów</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Uwierzytelnienie VPN TLS</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Domyślne</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Serwer</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Pasujące tematy</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Zdalny typ certyfikatu</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Plik klucza</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Dostosuj kierunek klucza</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Kierunek klucza</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Nieprawidłowa bramka</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Zapisano</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Zapytaj</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Niewymagane</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcje hasła</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nazwa grupy</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Hasło grupy</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Użyj uwierzytelnienia hybrydowego</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Plik CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Najpierw podłącz kabel sieciowy</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Przewodowa karta sieciowa</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Dodaj Połączenie Sieciowe</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Wybierz ustawienia</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Bezprzewodowa karta sieciowa</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Zamknij Hotspot</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Jeśli chcesz połączyć się z siecią bezprzewodową, najpierw wyłącz Hotspot</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Połącz z siecią ukrytą</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nie znaleziono</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adres MAC urządzenia</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Dostosuj MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokół</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Typ zabezpieczenia</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanał</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pasmo</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfejs</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sieci</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Podstawowy DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Prędkość</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Urządzenie wyłączone</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Połączono, brak dostępu do Internetu</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nie połączono</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel sieciowy odłączony</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Łączenie</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Uwierzytelnianie</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Uzyskiwanie adresu IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Połączono</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Rozłączono</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Wystąpił błąd</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Uzyskiwanie adresu</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Połączenie przewodowe</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Połączenie przewodowe %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Połączenie bezprzewodowe</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Połączenie bezprzewodowe %1</translation>
    </message>
</context>
</TS>